@@ -17,7 +17,6 @@ use AsyncAws\Core\Exception\InvalidArgument;
 use AsyncAws\Core\Exception\LogicException;
 use AsyncAws\Core\Exception\RuntimeException;
 use AsyncAws\Core\Exception\UnparsableResponse;
-use AsyncAws\Core\Stream\ResponseBodyResourceStream;
 use AsyncAws\Core\Stream\ResponseBodyStream;
 use AsyncAws\Core\Stream\ResultStream;
 use Psr\Log\LoggerInterface;
@@ -288,7 +287,7 @@ final class Response
      * @return array{
      *                resolved: bool,
      *                body_downloaded: bool,
-     *                response: \Symfony\Contracts\HttpClient\ResponseInterface,
+     *                response: ResponseInterface,
      *                status: int,
      *                }
      */
@@ -369,10 +368,6 @@ final class Response
     {
         $this->resolve();
 
-        if (\is_callable([$this->httpResponse, 'toStream'])) {
-            return new ResponseBodyResourceStream($this->httpResponse->toStream());
-        }
-
         if ($this->streamStarted) {
             throw new RuntimeException('Can not create a ResultStream because the body started being downloaded. The body was started to be downloaded in Response::wait()');
         }
