@@ -2,6 +2,8 @@
 
 namespace AsyncAws\Core\Stream;
 
+use AsyncAws\Core\Exception\RuntimeException;
+
 /**
  * Provides a Stream that can be read several time.
  *
@@ -66,6 +68,10 @@ final class RewindableStream implements RequestStream
         }
 
         $resource = fopen('php://temp', 'r+b');
+        if (false === $resource) {
+            throw new RuntimeException('Unable to create a temporary stream.');
+        }
+
         $this->fallback = ResourceStream::create($resource);
 
         foreach ($this->content as $chunk) {
