@@ -43,7 +43,7 @@ final class StringStream implements RequestStream
             return new self($content);
         }
 
-        throw new InvalidArgument(\sprintf('Expect content to be a "%s" or as "string". "%s" given.', RequestStream::class, \is_object($content) ? \get_class($content) : \gettype($content)));
+        throw new InvalidArgument(\sprintf('Expect content to be a "%s" or as "string". "%s" given.', RequestStream::class, get_debug_type($content)));
     }
 
     public function length(): int
