@@ -112,16 +112,16 @@ class StsClient extends AbstractApi
      * @param array{
      *   RoleArn: string,
      *   RoleSessionName: string,
-     *   PolicyArns?: null|array<PolicyDescriptorType|array>,
-     *   Policy?: null|string,
-     *   DurationSeconds?: null|int,
-     *   Tags?: null|array<Tag|array>,
-     *   TransitiveTagKeys?: null|string[],
-     *   ExternalId?: null|string,
-     *   SerialNumber?: null|string,
-     *   TokenCode?: null|string,
-     *   SourceIdentity?: null|string,
-     *   ProvidedContexts?: null|array<ProvidedContext|array>,
+     *   PolicyArns?: array<PolicyDescriptorType|array>|null,
+     *   Policy?: string|null,
+     *   DurationSeconds?: int|null,
+     *   Tags?: array<Tag|array>|null,
+     *   TransitiveTagKeys?: string[]|null,
+     *   ExternalId?: string|null,
+     *   SerialNumber?: string|null,
+     *   TokenCode?: string|null,
+     *   SourceIdentity?: string|null,
+     *   ProvidedContexts?: array<ProvidedContext|array>|null,
      *   '@region'?: string|null,
      * }|AssumeRoleRequest $input
      *
@@ -195,8 +195,8 @@ class StsClient extends AbstractApi
      * **Tags**
      *
      * (Optional) You can configure your IdP to pass attributes into your web identity token as session tags. Each session
-     * tag consists of a key name and an associated value. For more information about session tags, see Passing Session Tags
-     * in STS [^11] in the *IAM User Guide*.
+     * tag consists of a key name and an associated value. For more information about session tags, see Passing session tags
+     * using AssumeRoleWithWebIdentity [^11] in the *IAM User Guide*.
      *
      * You can pass up to 50 session tags. The plaintext session tag keys can’t exceed 128 characters and the values
      * can’t exceed 256 characters. For these and additional limits, see IAM and STS Character Limits [^12] in the *IAM
@@ -248,7 +248,7 @@ class StsClient extends AbstractApi
      * [^8]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html
      * [^9]: https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session
      * [^10]: https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session
-     * [^11]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html
+     * [^11]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_adding-assume-role-idp
      * [^12]: https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length
      * [^13]: https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html
      * [^14]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining
@@ -266,10 +266,10 @@ class StsClient extends AbstractApi
      *   RoleArn: string,
      *   RoleSessionName: string,
      *   WebIdentityToken: string,
-     *   ProviderId?: null|string,
-     *   PolicyArns?: null|array<PolicyDescriptorType|array>,
-     *   Policy?: null|string,
-     *   DurationSeconds?: null|int,
+     *   ProviderId?: string|null,
+     *   PolicyArns?: array<PolicyDescriptorType|array>|null,
+     *   Policy?: string|null,
+     *   DurationSeconds?: int|null,
      *   '@region'?: string|null,
      * }|AssumeRoleWithWebIdentityRequest $input
      *
@@ -347,6 +347,13 @@ class StsClient extends AbstractApi
                     'signService' => 'sts',
                     'signVersions' => ['v4'],
                 ];
+            case 'eusc-de-east-1':
+                return [
+                    'endpoint' => 'https://sts.eusc-de-east-1.amazonaws.eu',
+                    'signRegion' => 'eusc-de-east-1',
+                    'signService' => 'sts',
+                    'signVersions' => ['v4'],
+                ];
             case 'us-east-1-fips':
                 return [
                     'endpoint' => 'https://sts-fips.us-east-1.amazonaws.com',
@@ -389,6 +396,13 @@ class StsClient extends AbstractApi
                     'signService' => 'sts',
                     'signVersions' => ['v4'],
                 ];
+            case 'eu-isoe-west-1':
+                return [
+                    'endpoint' => 'https://sts.eu-isoe-west-1.cloud.adc-e.uk',
+                    'signRegion' => 'eu-isoe-west-1',
+                    'signService' => 'sts',
+                    'signVersions' => ['v4'],
+                ];
             case 'us-iso-east-1':
             case 'us-iso-west-1':
                 return [
@@ -397,6 +411,14 @@ class StsClient extends AbstractApi
                     'signService' => 'sts',
                     'signVersions' => ['v4'],
                 ];
+            case 'us-isob-east-1':
+            case 'us-isob-west-1':
+                return [
+                    'endpoint' => "https://sts.$region.sc2s.sgov.gov",
+                    'signRegion' => $region,
+                    'signService' => 'sts',
+                    'signVersions' => ['v4'],
+                ];
             case 'us-isof-east-1':
             case 'us-isof-south-1':
                 return [
@@ -405,20 +427,6 @@ class StsClient extends AbstractApi
                     'signService' => 'sts',
                     'signVersions' => ['v4'],
                 ];
-            case 'eu-isoe-west-1':
-                return [
-                    'endpoint' => 'https://sts.eu-isoe-west-1.cloud.adc-e.uk',
-                    'signRegion' => 'eu-isoe-west-1',
-                    'signService' => 'sts',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-isob-east-1':
-                return [
-                    'endpoint' => 'https://sts.us-isob-east-1.sc2s.sgov.gov',
-                    'signRegion' => 'us-isob-east-1',
-                    'signService' => 'sts',
-                    'signVersions' => ['v4'],
-                ];
         }
 
         return [
